// $Id: Menu.cpp,v 1.45 2014/09/08 14:35:54 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "DebugMenu.h"
#include "DefaultHelpText.h"
#include "HelpManager.h"
#include "Menu.h"
#include "Menu.moc"
#include "Singleton.h"
#include "SvgHelpText.h"
#include "TransparencyHelpText.h"
#include "XmlOptions.h"

//_______________________________________________
Menu::Menu( QWidget* parent ):
    QMenu( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu.\n" );

    // retrieve application
    Application& application( *Singleton::get().application<Application>() );

    // retrieve current TaskBar
    TaskBarBase& taskBar( *static_cast<TaskBarBase*>( parent ) );

    // task menu
    addAction( &taskBar.addButtonAction() );
    addAction( &taskBar.addSeparatorAction() );
    addAction( &taskBar.removeButtonAction() );
    addAction( &taskBar.editButtonAction() );
    addAction( &taskBar.editTaskListAction() );
    addSeparator();

    // taskBar menu
    addAction( &application.addTaskBarAction() );
    addAction( &application.removeTaskBarAction() );
    addAction( &taskBar.editAttributesAction() );

    addAction( &application.configurationAction() );
    QMenu *menu = addMenu( tr( "Flags" ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::LockPosition ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::AutoHide ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::StaysOnTop ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::Sticky ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::HideFromTaskBar ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::RoundCorners ) );
    menu->addAction( &taskBar.inverseColorsAction() );
    menu->addSeparator();
    menu->addAction( taskBar.flagAction( TaskBarAttributes::LockButtons ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::ShowName ) );
    menu->addAction( taskBar.flagAction( TaskBarAttributes::ExpandSeparators ) );
    menu->addAction( &taskBar.toggleToolTipAction() );

    menu->addSeparator();

    menu->addAction( &taskBar.noHighlightAction() );
    menu->addAction( &taskBar.highlightOnEnterAction() );
    menu->addAction( &taskBar.highlightOnClickAction() );

    addSeparator();

    // help manager
    Base::HelpManager* help( new Base::HelpManager( this ) );
    help->install( Transparency::helpText, false );
    help->install( Svg::helpText, false );
    help->install( Base::helpText, false );

    // help menu
    menu = addMenu( tr("Help" ) );
    menu->addAction( &help->displayAction() );
    #if HAVE_XCB
    menu->addAction( &taskBar.reloadBlurRegionAction() );
    #endif
    menu->addAction( &taskBar.reloadBackgroundAction() );
    menu->addSeparator();
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

    debugMenu->addAction( &taskBar.reloadBackgroundAction() );

    // exit
    addSeparator();
    addAction( &application.closeAction() );

    ensurePolished();

}
