// $Id: SeparatorPixmap.cpp,v 1.10 2013/04/29 18:27:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SeparatorPixmap.h"

#include <QImage>
#include <QPainter>

//_________________________________________________________________
SeparatorPixmap::SeparatorPixmap(
    int width,
    int height,
    TaskBarAttributes::Layout layout )
{

    // default colors
    QColor white( Qt::white ); white.setAlpha( 64 );
    QColor black( Qt::black ); black.setAlpha( 64 );

    // create image
    QImage image( width, height, QImage::Format_ARGB32_Premultiplied );
    image.fill( Qt::transparent );

    QPainter painter( &image );
    painter.setBrush( Qt::NoBrush );
    painter.setRenderHint( QPainter::Antialiasing, false );

    if( layout & TaskBarAttributes::Horizontal )
    {

        Q_ASSERT( width >= 2 );
        const int offset = (width - 2 )/2;
        painter.setPen( black );
        painter.drawLine( QPoint( offset, 0 ), QPoint( offset, height-1 ) );

        painter.setPen( white );
        painter.drawLine( QPoint( offset+1, 0 ), QPoint( offset+1, height-1 ) );

    } else if( layout & TaskBarAttributes::Vertical ) {

        Q_ASSERT( height >= 2 );
        const int offset = (height - 2 )/2;
        painter.setPen( black );
        painter.drawLine( QPoint( 0, offset ), QPoint( width-1, offset ) );

        painter.setPen( white );
        painter.drawLine( QPoint( 0, offset+1 ), QPoint( width-1, offset+1 ) );

    } else if( layout & TaskBarAttributes::Box ) {

        Q_ASSERT( width >= 2 && height >= 2 );
        const int hOffset = (width - 2 )/2;
        const int vOffset = (height - 2 )/2;

        painter.setPen( black );
        painter.drawPoint( hOffset, vOffset );
        painter.drawPoint( hOffset, vOffset+1 );
        painter.drawPoint( hOffset+1, vOffset );

        painter.setPen( white );
        painter.drawPoint( hOffset+1, vOffset+1 );

    }

    *this = fromImage( image );

}
