#ifndef TaskBarMinimum_h
#define TaskBarMinimum_h

// $Id: TaskBarMinimum.h,v 1.38 2014/02/10 11:08:16 hupereir Exp $


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file    TaskBarMinimum.h
\brief   transparent frame to display TaskButton(s)
\author  Hugo Pereira
\version $Revision: 1.38 $
\date    $Date: 2014/02/10 11:08:16 $
*/

#include "TaskBarBase.h"

//! TaskBar main widget
class TaskBarMinimum: public TaskBarBase
{

    //! qt meta object
    Q_OBJECT

    public:

    //! constructor
    TaskBarMinimum( QWidget *parent=0 );

    protected Q_SLOTS:

    //! root pixmap
    virtual void _updateRootPixmap( void );

    //! background background
    virtual void _updateBackgroundPixmap( void );

    protected:

    //!@name event handlers
    //@{

    //! resize event
    virtual void resizeEvent( QResizeEvent* );

    //@}

    //! resize the taskBar so that is is able to contain all buttons
    virtual void _resize( void );

    //! place buttons in the taskBar
    /*!  by default, first button starts at (0,0) */
    virtual void _placeButtons( void );

    //! adds offset to the buttons
    virtual void _addOffsets( void );

    //! draw buttons
    /*!
    if force is true, only buttons which are zooming are drawn
    returns true if at least one if zooming
    */
    virtual bool _drawButtons( QPaintDevice&, QRect );

    //! draw visible rect
    virtual void _drawVisibleRect( QPainter& );

    //! update minimum size
    virtual void _updateMinimumSize( void );

    //! update minimum rect
    virtual void _updateMinimumRectPosition( void );

    //! minimum size
    virtual QSize _minimumSize() const
    { return minimumRect_.size(); }

    //! minimum size
    virtual void _setMinimumSize( const QSize& size )
    { minimumRect_.setSize( size ); }

    //! minimum size
    virtual QRect _minimumRect() const
    { return minimumRect_; }

    //! minimum size
    virtual void _setMinimumRect( const QRect& rect )
    { minimumRect_ = rect; }

    //! update maximum size
    virtual void _updateMaximumSize( void );

    //! maximum size
    virtual const QSize& _maximumSize() const
    { return maximumSize_; }

    //! maximum size
    virtual void _setMaximumSize( const QSize& size )
    { maximumSize_ = size; }

    //! update visible rect
    virtual void _updateVisibleRect( void );

    //! update geometry (mask) for enter/leave event
    virtual bool _updateGeometry( Action action );

    //! visible rect
    virtual const QRect& _visibleRect( void ) const
    { return visibleRect_; }

    //! visible rect
    virtual QRect& _visibleRect( void )
    { return visibleRect_; }

    //! visible rect
    virtual bool _setVisibleRect( const QRect& rect )
    {
        if( visibleRect_ == rect ) return false;
        visibleRect_ = rect;
        return true;
    }

    //! root pixmap
    virtual QPixmap _rootPixmap( void ) const
    { return rootPixmap_; }

    //! root pixmap
    virtual QPixmap& _rootPixmap( void )
    { return rootPixmap_; }

    //! root pixmap
    virtual void _setRootPixmap( QPixmap pixmap )
    { rootPixmap_ = pixmap; }

    //! root pixmap needs update
    virtual const bool& _rootPixmapChanged( void ) const
    { return rootPixmapChanged_; }

    //! root pixmap needs update
    virtual void _setRootPixmapChanged( const bool& value )
    { rootPixmapChanged_ = value; }

    private:

    //! preload svg
    void _preloadSvg( void ) const;

    //! taskBar minimum size
    QRect minimumRect_;

    //! taskBar maximum size
    QSize maximumSize_;

    //! taskBar visible rect
    /*! this represents the rectangle that is shaded and on top of which the buttons are drawn */
    QRect visibleRect_;

    //! root pixmap
    QPixmap rootPixmap_;

    //! root pixmap needs update
    bool rootPixmapChanged_;

};

#endif
