// $Id: TaskParser.cpp,v 1.19 2014/02/10 20:50:48 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "File.h"
#include "TaskParser.h"
#include "XmlDef.h"
#include "XmlDocument.h"

#include <QFile>

//________________________________________________
bool TaskParser::read( const File& file )
{
    Debug::Throw( "TaskParser::Read.\n" );

    // reset attributes_list
    attributesList_.clear();

    // parse the file
    XmlDocument document;
    QFile qtfile( file );
    return document.setContent( &qtfile, error_ ) && _read( document, attributesList_ );

}

//________________________________________________
bool TaskParser::write( const File& file ) const
{

    Debug::Throw() << "TaskParser::Write - file: " << file << endl;

    // create document and read
    XmlDocument document;
    {
        QFile qtfile( file );
        document.setContent( &qtfile );
    }

    // read old attributes and look for modifications
    TaskBarAttributes::List attributesList;
    if( _read( document, attributesList ) && !attributesList.differs( attributesList_ ) )
    {
        Debug::Throw( "TaskParser::write - no changes to write.\n" );
        return true;

    }

    // create new top node and write
    QDomElement top = document.createElement( Xml::TaskList );
    foreach( const TaskBarAttributes& attributes, attributesList_ )
    { top.appendChild( attributes.domElement( document ) ); }

    // append topNode to document and write
    document.replaceChild( top );

    // write
    {
        QFile qfile( file );
        if( !qfile.open( QIODevice::WriteOnly ) ) return false;
        qfile.write( document.toByteArray() );
    }

    return true;

}

//___________________________________________________________
bool TaskParser::_read( const XmlDocument& document, TaskBarAttributes::List& attributes ) const
{

    // look for relevant element
    QDomNodeList topNodes = document.elementsByTagName( Xml::TaskList );
    if( topNodes.isEmpty() ) return false;

    for(QDomNode node = topNodes.at(0).firstChild(); !node.isNull(); node = node.nextSibling() )
    {

        QDomElement element = node.toElement();
        if( element.isNull() ) continue;

        QString tagName( element.tagName() );
        if( tagName == Xml::TaskBar ) attributes << TaskBarAttributes( element );

    }

    return true;

}
