
// $Id: main.cpp,v 1.19 2014/04/27 19:27:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "DefaultOptions.h"
#include "ErrorHandler.h"
#include "File.h"
#include "Singleton.h"
#include "SvgDefaultOptions.h"
#include "TransparencyDefaultOptions.h"
#include "Util.h"
#include "XmlMigration.h"
#include "XmlDef.h"

#include <QApplication>
#include <signal.h>
#include <unistd.h>

//_______________________________
//! to handle keyboard interuptions
void Interupt_CB( int sig );

//__________________________________________
int main (int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  Interupt_CB);
    signal(SIGTERM, Interupt_CB);

    // install error handler
    ErrorHandler::initialize();

    // default options
    installDefaultOptions();
    installSvgOptions();
    installTransparencyOptions();

    // rename old RC file into new one
    {
        File oldRCFile( File(".taskbar_qt4_rc").addPath( Util::home() ) );
        File newRCFile( XmlOptions::get().raw( "RC_FILE" ) );
        if( oldRCFile.exists() && !newRCFile.exists() )
        {
            Debug::Throw(0) << "taskbar - " << oldRCFile << " -> " << newRCFile << endl;
            oldRCFile.rename( newRCFile );
        }

    }

    // options
    XmlOptions::setFile( XmlOptions::get().raw( "RC_FILE" ) );
    XmlOptions::read();

    // debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) Debug::Throw() << XmlOptions::get() << endl;

    // migration
    XmlMigration( File(".taskbar_qt4_db").addPath(Util::home() ), QString(), Xml::TaskList ).run();

    // resources
    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    Q_INIT_RESOURCE( baseSvg );

    // application
    QApplication application( argc, argv );

    Application singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );

    // initialize and run
    if( singleton.initApplicationManager() )
    {  application.exec(); }

    return 0;

}


//_____________________________________________
void Interupt_CB( int sig )
{
    Debug::Throw() << "Interupt_CB - Recieved signal " << sig << endl;
    qApp->quit();
}
